ImmuneDB
========

[![Build Status](https://img.shields.io/travis/arosenfeld/immunedb/master.svg)](https://travis-ci.org/arosenfeld/immunedb) [![codecov](https://img.shields.io/codecov/c/github/arosenfeld/immunedb.svg)](https://codecov.io/gh/arosenfeld/immunedb) [![PyPI](https://img.shields.io/pypi/v/immunedb.svg)](https://pypi.python.org/pypi/ImmuneDB) [![Docker Pulls](https://img.shields.io/docker/pulls/arosenfeld/immunedb.svg)](https://hub.docker.com/r/arosenfeld/immunedb)

ImmuneDB is a Python module that facilitate efficient storage and analysis of
high-throughput B- and T-cell sequence data.

# Documentation
Installation and usage instructions can be found at [immunedb.com](http://immunedb.com)

# Citing
If you use ImmuneDB, please cite the tool as:

*ImmuneDB: A system for the analysis and exploration of high-throughput adaptive immune receptor sequencing data* Aaron M. Rosenfeld; Wenzhao Meng; Eline T. Luning Prak; Uri Hershberg Bioinformatics 2016; doi: 10.1093/bioinformatics/btw593
